module.exports = defineTest({
	description: 'treat getters and setters as function calls'
});
